@@ -63,7 +63,10 @@ class PCAReducer(Reducer):
         if self._embedding_cols is None:
             return self
         for k, v in self._pcas.items():
-            v.fit(df[self._embedding_dict[k]].dropna())
+            x_arr = df[self._embedding_dict[k]].dropna()
+            if len(x_arr) == 0:
+                continue
+            v.fit(x_arr)
         return self
 
     def transform(self, df: pd.DataFrame) -> pd.DataFrame:
@@ -71,8 +74,11 @@ class PCAReducer(Reducer):
             return df
         for k, v in self._pcas.items():
             cols = self._embedding_dict[k]
-            compressed_embedding = v.transform(df[cols].fillna(0.0))
-            embedding_len = compressed_embedding.shape[1]
-            df[cols[:embedding_len]] = compressed_embedding
-            df = df.drop(columns=cols[embedding_len:])
+            try:
+                compressed_embedding = v.transform(df[cols].fillna(0.0))
+                embedding_len = compressed_embedding.shape[1]
+                df[cols[:embedding_len]] = compressed_embedding
+                df = df.drop(columns=cols[embedding_len:])
+            except AttributeError:
+                pass
         return df
